BufferedReaderSpec

Trait BufferedReaderSpec 

trait BufferedReaderSpec {
    // Required methods
    fn buffer_priority(&self) -> usize;
    fn copy_to(&mut self, to: &mut (impl Write + ?Sized)) -> Result<u64>;
}
🔬This is a nightly-only experimental API. (alloc_io #154046)
Specialization of the read-write loop in generic_copy that reuses the internal buffer of a BufReader. If there’s no buffer then the writer side should be used instead.

Required Methods

fn buffer_priority(&self) -> usize

🔬This is a nightly-only experimental API. (alloc_io #154046)
fn copy_to(&mut self, to: &mut (impl Write + ?Sized)) -> Result<u64>

🔬This is a nightly-only experimental API. (alloc_io #154046)

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors